# Copyright (c) 2007-2008 gocept gmbh & co. kg
# See also LICENSE.txt
# $Id: i18n.py 5532 2008-01-24 13:39:39Z zagy $

import zope.i18nmessageid


MessageFactory = zope.i18nmessageid.MessageFactory('gocept.form')
